| count_pattern | R Documentation |
Counts the occurrences of a specific pattern in a sequence.
count_pattern(s, p)
s |
A character string containing the sequence |
p |
A character string containing the pattern to count |
Integer count of occurrences
data(sars_fragment)
count_pattern(sars_fragment, "ATTA")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.