| find_longest_orf | R Documentation |
Scans a DNA sequence in all 6 reading frames to find the longest open reading frame.
find_longest_orf(s)
s |
A character string containing the DNA sequence |
A character string of the longest translated protein sequence
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.