search_motif: Motif Searching

View source: R/discovery.R

search_motifR Documentation

Motif Searching

Description

Finds all occurrences of a motif in a sequence.

Usage

search_motif(s, p)

Arguments

s

A character string containing the sequence

p

A character string containing the motif (regex)

Value

A dataframe with the Start, End, and Match string


baseq documentation built on March 12, 2026, 1:07 a.m.