Learn R Programming

baseq (version 0.2.0)

find_longest_orf: Find Longest ORF

Description

Scans a DNA sequence in all 6 reading frames to find the longest open reading frame.

Usage

find_longest_orf(s)

Value

A character string of the longest translated protein sequence

Arguments

s

A character string containing the DNA sequence