| search_motif | R Documentation |
Finds all occurrences of a motif in a sequence.
search_motif(s, p)
s |
A character string containing the sequence |
p |
A character string containing the motif (regex) |
A dataframe with the Start, End, and Match string
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.