Learn R Programming

baseq (version 0.2.0)

search_motif: Motif Searching

Description

Finds all occurrences of a motif in a sequence.

Usage

search_motif(s, p)

Value

A dataframe with the Start, End, and Match string

Arguments

s

A character string containing the sequence

p

A character string containing the motif (regex)